@@ -1,5 +1,5 @@
 package Test::Expr;
-our $VERSION = '0.000003';
+our $VERSION = '0.000004';
 
 use 5.014; use warnings;
 use Keyword::Declare;
@@ -62,7 +62,7 @@ Test::Expr - Test an expression with better error messages
 
 =head1 VERSION
 
-This document describes Test::Expr version 0.000003
+This document describes Test::Expr version 0.000004
 
 
 =head1 SYNOPSIS
@@ -132,8 +132,7 @@ following functions from Test::More:
 
     ok $got eq $expected;            is        $got, $expected;
     ok $got ne $unexpected;          isnt      $got, $unexpected;
-    ok $got == $expected;            is_deeply $got, $expected;
-    ok $got ~~ $expected;            unlike    $got, $pattern;
+    ok $got ~~ $expected;            is_deeply $got, $expected;
     ok $got =~ $pattern;             like      $got, $pattern;
     ok $got !~ $pattern;             unlike    $got, $pattern;
     ok $obj->isa($classname);        is_ok     $got, $classname;
